==> qtjambi-xml-5.15.7-sources.jar: io/qt/xml/QDomProcessingInstruction.java <==
package io.qt.xml;


/**
 * <p>Represents an XML processing instruction</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qdomprocessinginstruction.html">QDomProcessingInstruction</a></p>
 */
public class QDomProcessingInstruction extends io.qt.xml.QDomNode
    implements java.lang.Cloneable
{
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qdomprocessinginstruction.html#QDomProcessingInstruction">QDomProcessingInstruction::QDomProcessingInstruction()</a></p>
     */
    public QDomProcessingInstruction(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QDomProcessingInstruction instance);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qdomprocessinginstruction.html#QDomProcessingInstruction-1">QDomProcessingInstruction::QDomProcessingInstruction(QDomProcessingInstruction)</a></p>
     */
    public QDomProcessingInstruction(io.qt.xml.QDomProcessingInstruction x){
        super((QPrivateConstructor)null);
        initialize_native(this, x);
    }
    
    private native static void initialize_native(QDomProcessingInstruction instance, io.qt.xml.QDomProcessingInstruction x);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qdomprocessinginstruction.html#data">QDomProcessingInstruction::data()const</a></p>
     */
    @io.qt.QtUninvokable
    public final java.lang.String data(){
        return data_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String data_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qdomprocessinginstruction.html#setData">QDomProcessingInstruction::setData(QString)</a></p>
     */
    @io.qt.QtUninvokable
    public final void setData(java.lang.String d){
        setData_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), d);
    }
    
    @io.qt.QtUninvokable
    private native void setData_native_cref_QString(long __this__nativeId, java.lang.String d);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qdomprocessinginstruction.html#target">QDomProcessingInstruction::target()const</a></p>
     */
    @io.qt.QtUninvokable
    public final java.lang.String target(){
        return target_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String target_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QDomProcessingInstruction(QPrivateConstructor p) { super(p); } 
    
    
    @Override
    public QDomProcessingInstruction clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private native QDomProcessingInstruction clone_native(long __this_nativeId);
}

==> qtjambi-xml-5.15.10-sources.jar: io/qt/xml/QDomProcessingInstruction.java <==
package io.qt.xml;


/**
 * <p>Represents an XML processing instruction</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qdomprocessinginstruction.html">QDomProcessingInstruction</a></p>
 */
public class QDomProcessingInstruction extends io.qt.xml.QDomNode
    implements java.lang.Cloneable
{
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qdomprocessinginstruction.html#QDomProcessingInstruction">QDomProcessingInstruction::QDomProcessingInstruction()</a></p>
     */
    public QDomProcessingInstruction(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QDomProcessingInstruction instance);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qdomprocessinginstruction.html#QDomProcessingInstruction-1">QDomProcessingInstruction::QDomProcessingInstruction(QDomProcessingInstruction)</a></p>
     */
    public QDomProcessingInstruction(io.qt.xml.QDomProcessingInstruction x){
        super((QPrivateConstructor)null);
        initialize_native(this, x);
    }
    
    private native static void initialize_native(QDomProcessingInstruction instance, io.qt.xml.QDomProcessingInstruction x);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qdomprocessinginstruction.html#data">QDomProcessingInstruction::data()const</a></p>
     */
    @io.qt.QtUninvokable
    public final java.lang.String data(){
        return data_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String data_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qdomprocessinginstruction.html#setData">QDomProcessingInstruction::setData(QString)</a></p>
     */
    @io.qt.QtUninvokable
    public final void setData(java.lang.String d){
        setData_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), d);
    }
    
    @io.qt.QtUninvokable
    private native void setData_native_cref_QString(long __this__nativeId, java.lang.String d);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qdomprocessinginstruction.html#target">QDomProcessingInstruction::target()const</a></p>
     */
    @io.qt.QtUninvokable
    public final java.lang.String target(){
        return target_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String target_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QDomProcessingInstruction(QPrivateConstructor p) { super(p); } 
    
    
    @Override
    public QDomProcessingInstruction clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private native QDomProcessingInstruction clone_native(long __this_nativeId);
}
